<!-- These are examples of badges you might want to add to your README:
     please update the URLs accordingly

[![Built Status](https://api.cirrus-ci.com/github/<USER>/bioRAT.svg?branch=main)](https://cirrus-ci.com/github/<USER>/bioRAT)
[![ReadTheDocs](https://readthedocs.org/projects/bioRAT/badge/?version=latest)](https://bioRAT.readthedocs.io/en/stable/)
[![Coveralls](https://img.shields.io/coveralls/github/<USER>/bioRAT/main.svg)](https://coveralls.io/r/<USER>/bioRAT)
[![PyPI-Server](https://img.shields.io/pypi/v/bioRAT.svg)](https://pypi.org/project/bioRAT/)
[![Conda-Forge](https://img.shields.io/conda/vn/conda-forge/bioRAT.svg)](https://anaconda.org/conda-forge/bioRAT)
[![Monthly Downloads](https://pepy.tech/badge/bioRAT/month)](https://pepy.tech/project/bioRAT)
[![Twitter](https://img.shields.io/twitter/url/http/shields.io.svg?style=social&label=Twitter)](https://twitter.com/bioRAT)
-->

[![PyPI-Server](https://img.shields.io/pypi/v/bioRAT.svg)](https://pypi.org/project/biorat/)
![Unit tests](https://github.com/BiocPy/bioRAT/actions/workflows/pypi-test.yml/badge.svg)

# Bioinformatics Random Awesome Tools (bioRAT)

Just a collection of useful data processing functions.

<!-- pyscaffold-notes -->

## Note

This project has been set up using PyScaffold 4.6. For details and usage
information on PyScaffold see https://pyscaffold.org/.
